function [ T,qs] = svinvertpa( T0,q0,p0,p )
%  This function accepts parcel temperature T0 (K), specific humidity q0,
%  (g/g),pressure p0 (hPa)
%  and a vector of pressure (hPa), and returns vectors of temperature (K),
%  and saturation specific humidity (g/g) along a pseudo-adiabat, according
%  to Bryan (2008)
%  Note:  This is not a very efficient algorithm
%
cp=1005;
Rd=287;
Rv=461;
Lv=2.555e6;  % Optimum value from Bryan (2008)
pref=1000;
Tref=290;
tolerance=0.002;
%
%  Vapor pressure, saturation vapor pressure, and entropy
%
e0=p0*q0/(0.622+q0);
Tc=T0-273.15;
es=6.112*exp(16.67*Tc/(243.5+Tc));
s0=cp*log(T0/Tref)-Rd*log(p0/pref)+Lv*q0/T0-q0*Rv*log(e0/es);
%
%   First guess
%
Tg=280;
psize=max(size(p));
T=zeros(1,psize);
qs=zeros(1,psize);
%
for i=1:psize,
    del=10;
    while del > tolerance
        %
        Tgc=Tg-273.15;
        esg=6.112*exp(17.67*Tgc/(243.5+Tgc));
        qsg=0.622*esg/(p(i)-esg);
        T(i)=Tref*exp((s0+Rd*log(p(i)/pref)-Lv*qsg/Tg)/cp);
        del=abs(T(i)-Tg);
        Tg=0.65*Tg+0.35*T(i);
    end
    T(i)=Tg;
    Tgc=Tg-273.15;
    esg=6.112*exp(17.67*Tgc/(243.5+Tgc));
    qs(i)=0.622*esg/(p(i)-esg);
end
end